searchData={"items":[{"type":"module","title":"Reed","doc":"Streaming RSS parser with a built-in `Req` plugin for network-enabled chunked streaming.","ref":"Reed.html"},{"type":"module","title":"Installation - Reed","doc":"```elixir\ndef deps do\n  [\n    {:reed, \"~> 0.1.0\"}\n  ]\nend\n```\n\nReed implements a Sax-based parser for RSS feeds using the [`Saxy`](https://github.com/qcam/saxy) library.\n\nYou can manually use the `Reed.Handler` (which implements the `Saxy.Handler` behaviour) with `Saxy` to parse\nstrings or from `Stream`s, but the killer feature of `Reed` is the `Reed.ReqPlugin` module, which powers the top-level\n`Reed.get` / `Reed.get!` API.\n\n`Reed.ReqPlugin` takes advantage of `Req`'s chunking capability to parse RSS feeds directly from over the network, applying\ntransformation functions to each RSS item lazily.\n\nThis means you do not have to store the entire RSS feed in memory or on disk to convert to a traditional Elixir `Stream`\n(as is required to use `Saxy.parse_stream/4`), but instead directly uses `Saxy.Partial` to parse chunk-by-chunk directly\nover the wire.\n\nThe `Reed.Transformers` module provides some convenient transformation functions to be used during the parsing.\n\nThe transformation pipeline is invoked whenever a new RSS item is read, and works with an accumulating state that persists\nduring the entire RSS read.","ref":"Reed.html#module-installation"},{"type":"module","title":"Examples - Reed","doc":"#","ref":"Reed.html#module-examples"},{"type":"module","title":"Get the feed metadata - Reed","doc":"```elixir\nimport Reed.Transformers\nReed.get!(rss_url, transform: transform(halt()))\n```\n\n#","ref":"Reed.html#module-get-the-feed-metadata"},{"type":"module","title":"Get all items in a list - Reed","doc":"```elixir\nimport Reed.Transformers\nReed.get!(rss_url, transform: transform(collect()))\n```\n\n#","ref":"Reed.html#module-get-all-items-in-a-list"},{"type":"module","title":"Get the first 5 items in a list - Reed","doc":"```elixir\nimport Reed.Transformers\nReed.get!(rss_url, transform: collect() |> limit(5) |> transform())\n```\n\n#","ref":"Reed.html#module-get-the-first-5-items-in-a-list"},{"type":"module","title":"Get all `itunes:` namespaced elements from the first 2 items as a list - Reed","doc":"```elixir\nimport Reed.Transformers\n\nReed.get!(rss_url,\n  transform:\n    transform_item(\n      &Map.filter(&1, fn\n        {<<\"itunes:\", _rest::binary>>, _v} -> true\n        _ -> false\n      end)\n    )\n    |> collect()\n    |> limit(2)\n    |> transform()\n)\n```","ref":"Reed.html#module-get-all-itunes-namespaced-elements-from-the-first-2-items-as-a-list"},{"type":"function","title":"Reed.get/2","doc":"Stream the RSS feed at the specified URL.","ref":"Reed.html#get/2"},{"type":"function","title":"Options - Reed.get/2","doc":"* `:transform` - The transformation pipeline to apply while streaming the RSS feed's items.\n Accepts passes through option to `Req`.","ref":"Reed.html#get/2-options"},{"type":"function","title":"Reed.get!/2","doc":"","ref":"Reed.html#get!/2"},{"type":"module","title":"Reed.Handler.State","doc":"","ref":"Reed.Handler.State.html"},{"type":"module","title":"Reed.ReqPlugin","doc":"A `Req` plugin for `Reed`.\n\nThis will stream the RSS feed over the network and apply the transformation to each item lazily.\n\nThis will store the result into the `Req.Response` struct under the `:rss` key in the `:private`\nfield.\n\nThis is streamed chunk-by-chunk, meaning you can stop reading the RSS feed at any point, and\nyou only store in memory what you decide to using the `:transform` option.\n\nYou can get the result using `Req.Response.get_private(response, :rss)`.","ref":"Reed.ReqPlugin.html"},{"type":"module","title":"Options - Reed.ReqPlugin","doc":"* `:transform` - The transformation function / pipeline to apply to each item in the RSS feed. Check\n                  the documentation for `Reed` for more information.","ref":"Reed.ReqPlugin.html#module-options"},{"type":"function","title":"Reed.ReqPlugin.attach/2","doc":"Attaches `Reed.ReqPlugin` to the given `Req.Request` struct.","ref":"Reed.ReqPlugin.html#attach/2"},{"type":"function","title":"Reed.ReqPlugin.setup_rss_stream/1","doc":"","ref":"Reed.ReqPlugin.html#setup_rss_stream/1"},{"type":"module","title":"Reed.Transformers","doc":"Convenient transformer functions to be used during parsing with `Reed.Handler`.\n\nWhen composing functions from `Reed.Transformers`, be aware that order matters\nand is preserved.\n\nFor example, if you use `transform_item/2` and `collect/2` in your pipeline,\nin order for `collect/2` to collect the transformed version of the item it\nmust come after `transform_item/2`.","ref":"Reed.Transformers.html"},{"type":"function","title":"Reed.Transformers.collect/1","doc":"Collects all items into a list.\n\nThe final list will be under the `:items` key in the state, and\nwill be in reverse order.","ref":"Reed.Transformers.html#collect/1"},{"type":"function","title":"Reed.Transformers.halt/1","doc":"Halt the RSS streaming after the current item.","ref":"Reed.Transformers.html#halt/1"},{"type":"function","title":"Reed.Transformers.limit/2","doc":"Keeps track of how many RSS feed items have been processed and will halt\nthe stream after the given # of RSS feed items have been processed.","ref":"Reed.Transformers.html#limit/2"},{"type":"macro","title":"Reed.Transformers.transform/1","doc":"A convenient macro that will format take your pipeline correctly\nif you have a pipeline composed entirely of functions with the following\nfunction signature: `(state::state, opts::list() \\ [])`\n\nThis is the function signature that all transformer functions within\n`Reed.Transformers` have.\n\nThis macro should always be called last in a transformation pipeline.","ref":"Reed.Transformers.html#transform/1"},{"type":"macro","title":"Example - Reed.Transformers.transform/1","doc":"The following two are equivalent:\n\n```elixir\nReed.get!(url, transform:\n  fn state ->\n    state\n    |> stop_after(1)\n    |> collect()\n  end\n)\n```\n\n```elixir\nReed.get!(url, transform:\n  stop_after(1)\n  |> collect()\n  |> transform()\n)\n```","ref":"Reed.Transformers.html#transform/1-example"},{"type":"function","title":"Reed.Transformers.transform_item/2","doc":"Transforms the current RSS feed item according to the\ngiven an arity-1 transformation function.","ref":"Reed.Transformers.html#transform_item/2"},{"type":"type","title":"Reed.Transformers.state/0","doc":"","ref":"Reed.Transformers.html#t:state/0"},{"type":"type","title":"Reed.Transformers.transformer/0","doc":"","ref":"Reed.Transformers.html#t:transformer/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}